@@ -1,4 +1,4 @@
 library("testthat")
 library("rKolada")
 
-test_check("rKolada")
+# test_check("rKolada")
